@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.63 2006/07/02 13:04:35 joern Exp $
+# $Id: Config.pm,v 1.65 2006/08/05 22:56:30 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -193,7 +193,7 @@ my %CONFIG_PARAMETER = (
     dvd_device => {
         label => __ "Default DVD device",
         type  => 'file',
-        value => "/dev/dvd",
+        value => "",
         dvd_button => 1,
     },
     selected_dvd_device => {
@@ -242,12 +242,12 @@ my %CONFIG_PARAMETER = (
     base_project_dir => {
         label => __ "Default data base directory",
         type  => 'dir',
-        value => "/CHANGE_ME",
+        value => "$ENV{HOME}/dvdrip-data",
     },
     dvdrip_files_dir => {
         label => __ "Default directory for .rip project files",
         type  => 'dir',
-        value => "/CHANGE_ME",
+        value => "$ENV{HOME}/dvdrip-data",
         rules => "dir-writable",
     },
     ogg_file_ext => {
@@ -275,7 +275,7 @@ my %CONFIG_PARAMETER = (
     default_video_codec => {
         label   => __ "Default video codec",
         type    => 'string',
-        value   => 'xvid4',
+        value   => 'xvid',
         presets => [
             "SVCD",   "VCD",  "XSVCD",   "XVCD",  "CVD",   "divx4",
             "divx5",  "xvid", "xvidcvs", "xvid2", "xvid3", "xvid4",
@@ -310,7 +310,7 @@ my %CONFIG_PARAMETER = (
     preferred_lang => {
         label   => __ "Preferred language",
         type    => 'popup',
-        value   => '<none>',
+        value   => '',
         presets => \@LANG_POPUP,
     },
     workaround_nptl_bugs => {
@@ -329,11 +329,11 @@ my %CONFIG_PARAMETER = (
 );
 
 my @CONFIG_ORDER = (
-    __ "Filesystem" => [
+    __ "Basic settings" => [
         qw(
             dvd_device
             base_project_dir   dvdrip_files_dir
-            ogg_file_ext
+            preferred_lang
             )
     ],
     __ "Commands" => [
@@ -350,9 +350,10 @@ my @CONFIG_ORDER = (
     ],
     __ "Miscellaneous options" => [
         qw(
-            default_video_codec  default_container
+            default_video_codec
+            default_container
+            ogg_file_ext
             default_bpp
-            preferred_lang
             default_subtitle_grab
             workaround_nptl_bugs nptl_ld_assume_kernel
             )
@@ -645,6 +646,31 @@ sub init_nptl_bug_workaround {
     1;
 }
 
+sub init_settings {
+    my $self = shift;
+    
+    if ( $self->get_value("dvd_device") eq "" ) {
+        $self->set_value( dvd_device => ($self->get_first_dvd_device || "/dev/dvd") );
+        $self->save;
+    }
+    
+    if ( $self->get_value("preferred_lang") eq "" ) {
+        my $lc_messages = POSIX::setlocale("LC_MESSAGES");
+        my ($lang) = split("_", $lc_messages, 2);
+        $lang = lc($lang);
+        $lang = "en" if $lang eq "c";
+        $self->set_value( preferred_lang => "<none>" );
+        foreach my $lang_list ( @LANG ) {
+            if ( $lang_list =~ /$lang -/i ) {
+                $self->set_value( preferred_lang => $lang_list );
+                last;
+            }
+        }
+    }
+    
+    1;
+}
+
 sub load {
     my $self = shift;
 
@@ -704,7 +730,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or die "can't write $filename";
-    print $fh q{# $Id: Config.pm,v 1.63 2006/07/02 13:04:35 joern Exp $},
+    print $fh q{# $Id: Config.pm,v 1.65 2006/08/05 22:56:30 joern Exp $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
@@ -827,6 +853,23 @@ sub selected_dvd_device_list {
     return \%devices;
 }
 
+sub get_first_dvd_device {
+    my $self = shift;
+    
+    my $href = $self->selected_dvd_device_list;
+
+    my $first_name;
+    my $first_device;
+    foreach my $device ( keys %{$href} ) {
+        if ( !$first_name || $first_name gt $href->{$device} ) {
+            $first_device = $device;
+            $first_name = $href->{$device};
+        }
+    }
+
+    return $first_device;
+}
+
 #---------------------------------------------------------------------
 # Test methods
 #---------------------------------------------------------------------
@@ -863,7 +906,7 @@ sub _executable {
     }
 
     if ( -x $file ) {
-        return __x( "{file} executable : Ok", file => $file );
+        return ( __x( "{file} executable : Ok", file => $file ), 1);
     }
     else {
         return __x( "{file} not found : NOT Ok", file => $file )
@@ -887,7 +930,7 @@ sub _abs_and_writable {
         return __x( "{file} not writable : NOT Ok", file => $value );
     }
     else {
-        return __x( "{file} writable : Ok", file => $value );
+        return (__x( "{file} writable : Ok", file => $value ), 1);
     }
 }
 
@@ -898,7 +941,7 @@ sub _numeric {
     my $value = $self->get_value($name);
 
     if ( $value =~ /^\d+$/ ) {
-        return __x( "{value} is numeric : Ok", value => $value );
+        return (__x( "{value} is numeric : Ok", value => $value ), 1);
     }
     else {
         return __x( "{value} isn't numeric : NOT Ok", value => $value );
@@ -911,28 +954,10 @@ sub _numeric_or_empty {
 
     my $value = $self->get_value($name);
 
-    return __ "is empty : Ok" if $value eq '';
+    return (__ "is empty : Ok", 1) if $value eq '';
     return $self->_numeric($name);
 }
 
-sub _cdrecord_device {
-    my $self = shift;
-    my ($name) = @_;
-
-    my $value = $self->get_value($name);
-
-    if ( $value =~ /^\d+,\d+,\d+$/ ) {
-        return "$value has format n,n,n : Ok";
-    }
-    elsif ( -e $value ) {
-        return __x( "{value} exists : Ok", value => $value );
-    }
-    else {
-        return __x( "{value} has not format n,n,n and is no file : NOT Ok",
-            value => $value );
-    }
-}
-
 sub _exists {
     my $self = shift;
     my ($name) = @_;
@@ -940,7 +965,7 @@ sub _exists {
     my $value = $self->get_value($name);
 
     if ( -e $value ) {
-        return __x( "{value} exists : Ok", value => $value );
+        return (__x( "{value} exists : Ok", value => $value ), 1);
     }
     else {
         return __x( "{value} doesn't exist : NOT Ok", value => $value );
@@ -954,7 +979,7 @@ sub _one_of_these {
     my $value = $self->get_value($name);
 
     foreach my $val ( @{$lref} ) {
-        return __x( "'{value}' is known : Ok", value => $value )
+        return (__x( "'{value}' is known : Ok", value => $value ), 1)
             if $val eq $value;
     }
 
