@@ -1,4 +1,4 @@
-# $Id: Depend.pm,v 1.16 2006/03/27 21:29:07 joern Exp $
+# $Id: Depend.pm,v 1.20 2006/07/02 15:07:06 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::Depend;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 @ISA = qw ( Video::DVDRip::Base );
 
@@ -22,8 +21,8 @@ use strict;
 my @DVDRIP_BIN_FILES = qw (
     dvdrip              execflow
     dvdrip-master       dvdrip-multitee
-    dvdrip-progress     dvdrip-tet
-    dvdrip-splitpipe    dvdrip-subpng
+    dvdrip-progress     dvdrip-splitpipe
+    dvdrip-subpng
 );
 
 my $ORDER = 0;
@@ -207,72 +206,6 @@ my %TOOLS = (
         min       => "1.6.0",
         suggested => "1.6.2",
     },
-    cdrdao => {
-        order       => ++$ORDER,
-        command     => "cdrdao",
-        comment     => __ "Needed for (S)VCD burning",
-        optional    => 1,
-        get_version => sub {
-            qx[cdrdao show-toc -h 2>&1]
-                =~ /version\s+(\d+\.\d+\.\d+(\.\d+)?)/i;
-            return $1;
-        },
-        convert   => 'default',
-        min       => "1.1.7",
-        suggested => "1.1.9",
-    },
-    vcdimager => {
-        order       => ++$ORDER,
-        command     => "vcdimager",
-        comment     => __ "Needed for (S)VCD burning",
-        optional    => 1,
-        get_version => sub {
-            qx[vcdimager -V 2>&1] =~ /vcdimager.*?\s+(\d+\.\d+(\.\d+)?)/i;
-            return $1;
-        },
-        convert   => 'default',
-        min       => "0.7.12",
-        suggested => "0.7.21",
-    },
-    mkisofs => {
-        order       => ++$ORDER,
-        command     => "mkisofs",
-        comment     => __ "Needed for AVI/OGG burning",
-        optional    => 1,
-        get_version => sub {
-            qx[mkisofs -version 2>&1] =~ /mkisofs\s+(\d+\.\d+(\.\d+)?)/i;
-            return $1;
-        },
-        convert   => 'default',
-        min       => "1.15",
-        suggested => "2.0",
-    },
-    cdrecord => {
-        order       => ++$ORDER,
-        command     => "cdrecord",
-        comment     => __ "Needed for AVI/OGG burning on CD",
-        optional    => 1,
-        get_version => sub {
-            qx[cdrecord -version 2>&1] =~ /(\d+\.\d+(\.\d+)?)/i;
-            return $1;
-        },
-        convert   => 'default',
-        min       => "0.7.12",
-        suggested => "2.6.11",
-    },
-    dvdrecord => {
-        order       => ++$ORDER,
-        command     => "dvdrecord",
-        comment     => __ "Needed for AVI/OGG burning on DVD",
-        optional    => 1,
-        get_version => sub {
-            qx[dvdrecord -version 2>&1] =~ /(\d+\.\d+(\.\d+)?)/i;
-            return $1;
-        },
-        convert   => 'default',
-        min       => "0.2.0",
-        suggested => "0.2.1",
-    },
     xine => {
         order       => ++$ORDER,
         command     => "xine",
@@ -299,6 +232,19 @@ my %TOOLS = (
         min       => "2.2",
         suggested => "2.4",
     },
+    hal => {
+        order       => ++$ORDER,
+        command     => "/usr/bin/lshal",
+        comment     => __"Used for DVD device scanning",
+        optional    => 1,
+        get_version => sub {
+            qx[/usr/bin/lshal -v 2>&1] =~ /version\s+(\d+\.\d+(\.\d+)?)/i;
+            return $1;
+        },
+        convert   => 'default',
+        min       => "0.5",
+        suggested => "0.5.7",
+    },
 );
 
 my $OBJECT;
