@@ -1,4 +1,4 @@
-# $Id: FilterList.pm,v 1.9 2006/03/29 20:23:37 joern Exp $
+# $Id: FilterList.pm,v 1.11 2006/06/17 12:47:15 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::FilterList;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Base;
 
@@ -21,6 +20,8 @@ use FileHandle;
 
 use Video::DVDRip::CPAN::Scanf;
 
+my $DEBUG = 0;
+
 my $FILTER_LIST;
 my %FILTER_SELECTION_CB = (
     logo => sub {
@@ -123,6 +124,8 @@ sub get_filter_list {
     my $transcode_modpath = qx[ tcmodinfo -p 2>/dev/null ];
     chomp $transcode_modpath;
 
+    $DEBUG && print STDERR "transcode module path: $transcode_modpath\n";
+
     # empty list if tcmodinfo not available
     return $FILTER_LIST = $class->new() if not $transcode_modpath;
 
@@ -186,7 +189,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or confess "can't write $filename";
-    print $fh q{# $Id: FilterList.pm,v 1.9 2006/03/29 20:23:37 joern Exp $},
+    print $fh q{# $Id: FilterList.pm,v 1.11 2006/06/17 12:47:15 joern Exp $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
@@ -223,7 +226,7 @@ sub scan {
     foreach my $filter_name (@filter_names) {
         my $filter
             = Video::DVDRip::Filter->new( filter_name => $filter_name );
-        next if not $filter->capabilities;
+        next if !$filter || !$filter->capabilities;
         $filters{$filter_name} = $filter;
     }
 
@@ -247,7 +250,6 @@ sub get_filter {
 
 package Video::DVDRip::Filter;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use Text::Wrap;
@@ -275,14 +277,29 @@ sub new {
     my $class         = shift;
     my %par           = @_;
     my ($filter_name) = @par{'filter_name'};
-    0 && print "\n$filter_name:\n";
-    my $config = qx[ tcmodinfo -i $filter_name 2>/dev/null ];
+
+    $DEBUG && print STDERR "Scan: tcmodinfo -i $filter_name ... ";
+
+    my $config;
+    eval {
+        local $SIG{ALRM} = sub { die "alarm" };
+        alarm 2;
+        $config = qx[ tcmodinfo -i $filter_name 2>/dev/null ];
+        alarm 0;
+    };
+
+    if ( $@ ) {
+        $DEBUG && print STDERR "TIMEOUT\n";
+        return;
+    }
+    
+    $DEBUG && print STDERR "OK\n------\n$config\n------\n";
 
     my $line;
     my ( %options, @options );
 
     my ( $desc, $version, $author, $capabilities, $frames_needed );
-    my $in_config;
+    my $in_config = Video::DVDRip::Base->version("transcode") >= 10100;
 
     while ( $config =~ /(.*)/g ) {
         $line = $1;
@@ -291,7 +308,6 @@ sub new {
             $in_config = 1;
         }
         next if $line !~ /^"/;
-        0 && print "$line\n";
         if ( not $desc ) {
             my @csv_fields = ( $line =~ /"([^"]+)"/g );
             shift @csv_fields;
@@ -307,10 +323,13 @@ sub new {
             config      => $line,
             filter_name => $filter_name,
         );
+        return if $option->option_name !~ /^\w+$/;
         $options{ $option->option_name } = $option;
         push @options, $option;
     }
 
+    $capabilities =~ s/O/E/ if $filter_name eq 'logoaway';
+
     my $self = {
         filter_name     => $filter_name,
         desc            => $desc,
@@ -330,7 +349,7 @@ sub get_option {
     my %par           = @_;
     my ($option_name) = @par{'option_name'};
 
-    croak "Option '$option_name' unknown"
+    croak "Option '$option_name' unknown for filter '".$self->filter_name."'"
         if not exists $self->options_by_name->{$option_name};
 
     return $self->options_by_name->{$option_name};
@@ -374,15 +393,63 @@ sub get_info {
     return \@info;
 }
 
+sub av_type {
+    my $self = shift;
+
+    my $info = "";
+    $info .= __("Video").", " if $self->can_video;
+    $info .= __("Audio").", " if $self->can_audio;
+    $info =~ s/, $//;
+
+    return $info;
+}
+
+sub colorspace_type {
+    my $self = shift;
+
+    return "--" if !$self->can_video;
+    
+    my $info = "";
+    $info .= "RGB, " if $self->can_rgb;
+    $info .= "YUV, " if $self->can_yuv;
+    $info =~ s/, $//;
+
+    return $info;
+}
+
+sub pre_post_type {
+    my $self = shift;
+
+    my $info = "";
+    $info .= "PRE, "  if $self->is_pre;
+    $info .= "POST, " if $self->is_post;
+    $info =~ s/, $//;
+    $info ||= "unknown";
+
+    return $info;
+}
+
+sub multiple_type {
+    my $self = shift;
+    return $self->can_multiple ? __"Yes" : __"No";
+}
+
 sub get_selection_cb {
     my $self = shift;
 
     return $FILTER_SELECTION_CB{ $self->filter_name };
 }
 
+sub get_dummy_instance {
+    my $self = shift;
+    return Video::DVDRip::FilterSettingsInstance->new (
+        id          => -1,
+        filter_name => $self->filter_name
+    );
+}
+
 package Video::DVDRip::FilterOption;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use Text::Wrap;
@@ -417,6 +484,12 @@ sub new {
         push @csv_fields, "", "";
     }
 
+    # cpaudio reports '%c' - stupid, %c scans ASCII code
+    $format = '%s' if $format eq '%c';
+
+    # logoaway reports '%2x' - stupid, we get spaces this way
+    $format =~ s/\%2x/\%02x/g;
+
     my $scan_format = $format;
     $scan_format =~ s/\%\%//g;    # eliminate quoted %
     my $default_format = $format;
@@ -426,12 +499,6 @@ sub new {
     my @default_values
         = Video::DVDRip::CPAN::Scanf::sscanf( $default_format, $default );
 
-    0
-        && $filter_name eq 'logo'
-        && print "[$filter_name] $name: $format = $default => ",
-        join( " ", @default_values ), " - ", join( " ", @field_formats ),
-        "\n";
-
     my @fields;
     while (@csv_fields) {
         my $range_from = shift @csv_fields;
@@ -440,11 +507,11 @@ sub new {
 
         push @fields,
             Video::DVDRip::FilterOptionField->new(
-            default    => shift @default_values,
-            range_from => $range_from,
-            range_to   => $range_to,
-            fractional => ( $type eq 'f' ),
-            text       => ( $type eq 's' ),
+                default    => shift @default_values,
+                range_from => $range_from,
+                range_to   => $range_to,
+                fractional => ( $type eq 'f' ),
+                text       => ( $type eq 's' ),
             );
     }
 
@@ -465,14 +532,13 @@ sub new {
 sub get_wrapped_desc {
     my $self = shift;
 
-    $Text::Wrap::columns = 30;
+    local($Text::Wrap::columns) = 24;
 
     return join( "\n", wrap( "", "", $self->desc ) );
 }
 
 package Video::DVDRip::FilterOptionField;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 sub default			{ shift->{default}			}
 sub range_from			{ shift->{range_from}			}
@@ -498,12 +564,11 @@ sub text			{ shift->{text}				}
 
 sub new {
     my $class = shift;
-    my %par   = @_;
-    my ( $default, $range_from, $range_to, $fractional, $switch, $text )
-        = @par{
-        'default', 'range_from', 'range_to', 'fractional',
-        'switch',  'text'
-        };
+    my %par = @_;
+    my  ($default, $range_from, $range_to, $fractional, $switch) =
+    @par{'default','range_from','range_to','fractional','switch'};
+    my  ($text) =
+    @par{'text'};
 
     my ( $checkbox, $combo );
 
@@ -514,6 +579,7 @@ sub new {
     $range_from = -99999999
         if $range_from eq ''
         or $range_from =~ /\D/;
+
     $range_to = 99999999
         if $range_to eq ''
         or $range_to =~ /\D/;
