@@ -1,4 +1,4 @@
-# $Id: ClipImage.pm,v 1.4 2006/04/01 11:27:14 joern Exp $
+# $Id: ClipImage.pm,v 1.6 2006/07/02 08:31:10 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -15,7 +15,15 @@ use strict;
 use base qw( Gtk2::Ex::FormFactory::Widget );
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
+
+(
+    top    => __"Top",
+    bottom => __"Bottom",
+    left   => __"Left",
+    right  => __"Right",
+);
+
+__"Conformance check:";
 
 sub get_type { "dvdrip_clip_image" }
 
