@@ -1,4 +1,4 @@
-# $Id: Preview.pm,v 1.18 2006/04/10 19:49:28 joern Exp $
+# $Id: Preview.pm,v 1.20 2006/06/17 12:53:39 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -10,7 +10,6 @@
 
 package Video::DVDRip::GUI::Preview;
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use strict;
@@ -40,6 +39,9 @@ sub set_selection_cb		{ shift->{selection_cb}		= $_[1]	}
 sub gdk_input			{ shift->{gdk_input}			}
 sub set_gdk_input		{ shift->{gdk_input}		= $_[1]	}
 
+sub settings_applied            { shift->{settings_applied}             }
+sub set_settings_applied        { shift->{settings_applied}     = $_[1] }
+
 sub new {
     my $class = shift;
     my %par   = @_;
@@ -98,13 +100,15 @@ sub open {
 
     require Video::DVDRip::GUI::Pipe;
 
-    my $transcode_pipe = Video::DVDRip::GUI::Pipe->new(
+    my $transcode_pipe;
+    $transcode_pipe = Video::DVDRip::GUI::Pipe->new(
         command     => $command,
         need_output => 0,
         cb_finished => sub {
             my $eof_cb = $self->eof_cb;
-            &$eof_cb()  if $eof_cb;
+            &$eof_cb($transcode_pipe->output =~ /EXECFLOW_OK/) if $eof_cb;
             $self->stop if not $self->stop_in_progress;
+            $transcode_pipe = undef;
             1;
         },
     );
@@ -120,9 +124,9 @@ sub open {
         200,
         sub {
             if ( not -e $socket_file ) {
-                if ( time - $start_time >= 10 ) {
+                if ( time - $start_time >= 2 ) {
                     $self->stop;
-                    Glib::Source->remove($timer);
+                    Glib::Source->remove($timer) if $timer;
                     croak "msg:Couldn't start transcode.";
                 }
                 return 1;
@@ -184,7 +188,7 @@ sub apply_filter_settings {
 
     my $max_frames_needed = $title->tc_filter_settings->get_max_frames_needed,
 
-        my $transcode_remote = $self->transcode_remote;
+    my $transcode_remote = $self->transcode_remote;
 
     foreach my $config ( @{$config_strings} ) {
         $transcode_remote->config_filter(
@@ -202,8 +206,9 @@ sub apply_filter_settings {
     $transcode_remote->preview(
         command => "draw",
         options => $max_frames_needed,
-        )
-        if $transcode_remote->paused;
+    ) if $transcode_remote->paused;
+
+    $self->set_settings_applied(1);
 
     1;
 }
@@ -234,7 +239,8 @@ sub stop {
             if $self->transcode_remote;
         $self->transcode_pipe->cancel
             if $self->transcode_pipe;
-        Gtk2::Helper->remove_watch( $self->gdk_input );
+        Gtk2::Helper->remove_watch( $self->gdk_input )
+            if $self->gdk_input;
         $self->close;
     }
 
@@ -255,6 +261,8 @@ sub close {
 sub pause {
     my $self = shift;
 
+    $self->set_settings_applied(0);
+
     $self->transcode_remote->preview( command => "pause", );
 
     return $self->transcode_remote->paused;
@@ -262,6 +270,7 @@ sub pause {
 
 sub paused {
     my $self = shift;
+    return 0 if ! $self->transcode_remote;
     return $self->transcode_remote->paused;
 }
 
