@@ -1,4 +1,4 @@
-# $Id: Progress.pm,v 1.35 2006/03/31 21:47:55 joern Exp $
+# $Id: Progress.pm,v 1.37 2006/07/02 08:32:28 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -13,7 +13,6 @@ package Video::DVDRip::GUI::Progress;
 use base qw( Video::DVDRip::GUI::Base );
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use strict;
 use Carp;
@@ -218,6 +217,7 @@ sub build_details_ff {
                         width      => 640,
                         height     => 300,
                         expand     => 1,
+                        # add_columns => [ "diskspace_consumed", "diskspace_freed" ],
                     ),
                     Gtk2::Ex::FormFactory::HBox->new(
                         name       => "progress_detail_buttons",
