@@ -1,4 +1,4 @@
-# $Id: ClipZoom.pm,v 1.12 2006/04/01 11:28:22 joern Exp $
+# $Id: ClipZoom.pm,v 1.15 2006/07/02 13:49:16 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -13,7 +13,6 @@ package Video::DVDRip::GUI::Project::ClipZoom;
 use base qw( Video::DVDRip::GUI::Base );
 
 use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use Carp;
 use strict;
@@ -288,6 +287,8 @@ sub build_adjust_form {
                         clicked_hook => sub { $self->apply_preset_values },
                         active_cond    => sub { !$self->progress_is_active },
                         active_depends => "progress.is_active",
+                        tip            => __"Overwrites all Clip & Zoom settings from the selected ".
+                                            "preset and regenerates the preview images.",
                     ),
 
                     #-- Separator
@@ -348,6 +349,8 @@ sub build_adjust_form {
                         clicked_hook => sub { $self->make_previews },
                         active_cond    => sub { !$self->progress_is_active },
                         active_depends => "progress.is_active",
+                        tip          => __"Generates new preview images based ".
+                                          "on the actual settings",
                     ),
 
                     #-- 2nd Clipping
@@ -384,7 +387,9 @@ sub build_adjust_form {
                     Gtk2::Ex::FormFactory::Button->new(
                         label        => __ "Move 2nd clipping to 1st",
                         stock        => "dvdrip-clip-move",
-                        clicked_hook => sub { $self->move_clip2_to_clip1 }
+                        clicked_hook => sub { $self->move_clip2_to_clip1 },
+                        tip          => __"Turns second clipping into first clipping. ".
+                                          "This is possible only with high quality scaling."
                     ),
 
                     #-- Separator
@@ -439,12 +444,16 @@ sub build_adjust_form {
                         label        => __ "Calc height",
                         stock        => "dvdrip-calc-height",
                         clicked_hook =>
-                            sub { $self->calc_zoom( height => 1 ) }
+                            sub { $self->calc_zoom( height => 1 ) },
+                        tip          => __"Calculates the height based on the given width ".
+                                          "with correct aspect ratio",
                     ),
                     Gtk2::Ex::FormFactory::Button->new(
                         label        => __ "Calc width",
                         stock        => "dvdrip-calc-width",
-                        clicked_hook => sub { $self->calc_zoom( width => 1 ) }
+                        clicked_hook => sub { $self->calc_zoom( width => 1 ) },
+                        tip          => __"Calculates the width based on the given height ".
+                                          "with correct aspect ratio",
                     ),
 
                     #-- Fast resizing
@@ -454,6 +463,8 @@ sub build_adjust_form {
                     ),
                     Gtk2::Ex::FormFactory::YesNo->new(
                         attr => "title.tc_fast_resize",
+                        true_label => __"Yes",
+                        false_label  => __"No",
                     ),
                     Gtk2::Ex::FormFactory::Button->new(
                         label        => __ "Open zoom calculator",
