@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.56 2006/07/02 13:48:36 joern Exp $
+# $Id: Project.pm,v 1.57 2006/08/05 21:55:01 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -114,6 +114,11 @@ sub new {
 
     $self->set_content($content);
 
+    if ( !$self->dvd_device ) {
+        my $dvd_device = $self->config_object->get_first_dvd_device;
+        $self->set_dvd_device($dvd_device);
+    }
+
     return $self;
 }
 
@@ -151,7 +156,7 @@ sub save {
     my $fh = FileHandle->new;
 
     open( $fh, "> $filename" ) or confess "can't write $filename";
-    print $fh q{# $Id: Project.pm,v 1.56 2006/07/02 13:48:36 joern Exp $},
+    print $fh q{# $Id: Project.pm,v 1.57 2006/08/05 21:55:01 joern Exp $},
         "\n";
     print $fh
         "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
@@ -175,7 +180,7 @@ sub save {
 sub backup_copy {
     my $self = shift;
 
-    $self->save( filename => $self->snap_dir . "/backup.rip" );
+    $self->save( $self->snap_dir . "/backup.rip" );
 
     1;
 }
